@@ -54,6 +54,8 @@ def create_from_template(name, template_name, directory):
         directory = os.getcwd()
 
     project_directory = path.join(directory, name)
+    if path.exists(project_directory):
+        raise errors.BadDirectory(project_directory)
 
     _download_templates_repositories()
     _copy_template(template_name, project_directory)
@@ -133,6 +135,7 @@ class TemplateRust(Template):
         launch_path = path.join(self.directory, ".vscode", "launch.json")
         tasks_path = path.join(self.directory, ".vscode", "tasks.json")
         debug_main_path = path.join(self.directory, "debug", "src", "main.rs")
+        test_paths = utils.list_files(path.join(self.directory, "test"))
 
         logger.info("Updating cargo files...")
 
@@ -177,6 +180,13 @@ class TemplateRust(Template):
             ]
         )
 
+        self._replace_in_files(
+            test_paths,
+            [
+                (f"adder.wasm", f"myadder.wasm")
+            ]
+        )
+
     def _replace_in_files(self, files, replacements):
         for file in files:
             content = utils.read_file(file)
