@@ -1,10 +1,12 @@
 import json
 import logging
 import os
+import os.path
 import pathlib
 import stat
 import tarfile
 import zipfile
+from typing import List
 
 import toml
 
@@ -63,6 +65,10 @@ def write_toml_file(filename, data):
         toml.dump(data, f)
 
 
+def dump_out_json(data, outfile):
+    json.dump(data, outfile, indent=4)
+
+
 def get_subfolders(folder):
     return [item.name for item in os.scandir(folder) if item.is_dir() and not item.name.startswith(".")]
 
@@ -82,3 +88,9 @@ def find_in_dictionary(dictionary, compound_path):
             break
 
     return node
+
+
+def list_files(folder: str) -> List[str]:
+    files = os.listdir(folder)
+    files = [os.path.join(folder, f) for f in files]
+    return files
